@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Database-backed Periodic Tasks."""
 # :copyright: (c) 2016, Ask Solem.
 #             All rights reserved.
@@ -7,7 +6,9 @@ import re
 
 from collections import namedtuple
 
-__version__ = '2.1.0'
+import django
+
+__version__ = '2.2.1'
 __author__ = 'Asif Saif Uddin, Ask Solem'
 __contact__ = 'auvipy@gmail.com, ask@celeryproject.org'
 __homepage__ = 'https://github.com/celery/django-celery-beat'
@@ -30,4 +31,5 @@ del(re)
 
 __all__ = []
 
-default_app_config = 'django_celery_beat.apps.BeatConfig'
+if django.VERSION < (3, 2):
+    default_app_config = 'django_celery_beat.apps.BeatConfig'
