@@ -38,7 +38,17 @@ SINGULAR_PERIODS = (
     (MICROSECONDS, _('Microsecond')),
 )
 
-SOLAR_SCHEDULES = [(x, _(x)) for x in sorted(schedules.solar._all_events)]
+SOLAR_SCHEDULES = [
+    ("dawn_astronomical", _("Astronomical dawn")),
+    ("dawn_civil", _("Civil dawn")),
+    ("dawn_nautical", _("Nautical dawn")),
+    ("dusk_astronomical", _("Astronomical dusk")),
+    ("dusk_civil", _("Civil dusk")),
+    ("dusk_nautical", _("Nautical dusk")),
+    ("solar_noon", _("Solar noon")),
+    ("sunrise", _("Sunrise")),
+    ("sunset", _("Sunset")),
+]
 
 
 def cronexp(field):
@@ -57,7 +67,8 @@ def crontab_schedule_celery_timezone():
     except AttributeError:
         return 'UTC'
     return CELERY_TIMEZONE if CELERY_TIMEZONE in [
-        choice[0].zone for choice in timezone_field.TimeZoneField.CHOICES
+        choice[0].zone for choice in timezone_field.
+        TimeZoneField.default_choices
     ] else 'UTC'
 
 
@@ -106,13 +117,13 @@ class SolarSchedule(models.Model):
         spec = {'event': schedule.event,
                 'latitude': schedule.lat,
                 'longitude': schedule.lon}
+
+        # we do not check for MultipleObjectsReturned exception here because
+        # the unique_together constraint safely prevents from duplicates
         try:
             return cls.objects.get(**spec)
         except cls.DoesNotExist:
             return cls(**spec)
-        except MultipleObjectsReturned:
-            cls.objects.filter(**spec).delete()
-            return cls(**spec)
 
     def __str__(self):
         return '{0} ({1}, {2})'.format(
@@ -172,8 +183,7 @@ class IntervalSchedule(models.Model):
         except cls.DoesNotExist:
             return cls(every=every, period=period)
         except MultipleObjectsReturned:
-            cls.objects.filter(every=every, period=period).delete()
-            return cls(every=every, period=period)
+            return cls.objects.filter(every=every, period=period).first()
 
     def __str__(self):
         readable_period = None
@@ -225,8 +235,7 @@ class ClockedSchedule(models.Model):
         except cls.DoesNotExist:
             return cls(**spec)
         except MultipleObjectsReturned:
-            cls.objects.filter(**spec).delete()
-            return cls(**spec)
+            return cls.objects.filter(**spec).first()
 
 
 class CrontabSchedule(models.Model):
@@ -339,8 +348,7 @@ class CrontabSchedule(models.Model):
         except cls.DoesNotExist:
             return cls(**spec)
         except MultipleObjectsReturned:
-            cls.objects.filter(**spec).delete()
-            return cls(**spec)
+            return cls.objects.filter(**spec).first()
 
 
 class PeriodicTasks(models.Model):
@@ -536,7 +544,7 @@ class PeriodicTask(models.Model):
         verbose_name_plural = _('periodic tasks')
 
     def validate_unique(self, *args, **kwargs):
-        super(PeriodicTask, self).validate_unique(*args, **kwargs)
+        super().validate_unique(*args, **kwargs)
 
         schedule_types = ['interval', 'crontab', 'solar', 'clocked']
         selected_schedule_types = [s for s in schedule_types
@@ -570,7 +578,7 @@ class PeriodicTask(models.Model):
             self.last_run_at = None
         self._clean_expires()
         self.validate_unique()
-        super(PeriodicTask, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
     def _clean_expires(self):
         if self.expire_seconds is not None and self.expires:
